#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-A4plcOSWKmsCyR19Vw36QS
key:                  stack-2.9.3.1-A4plcOSWKmsCyR19Vw36QS
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  e7408a326fe171da61bed21c8c6f2a9c
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-A4plcOSWKmsCyR19Vw36QS
depends:
    Cabal-3.10.3.0 aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-EbUDRvGBhSA7HJDnawsw6S array-0.5.6.0
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX
    attoparsec-0.14.4-8ZKlPX7xLQdALFlvUv2KV7 base-4.18.2.1
    base64-bytestring-1.2.1.0-6xAAZg1ImCJ4f2ZpizqLQy
    bytestring-0.11.5.3 casa-client-0.0.3-8ikvCmnNGaYH40JaBqNUpL
    casa-types-0.0.3-1rSQf0n2VBvDAbvA1PwbR9
    colour-2.3.6-IgsktTWwFiq37ufwY4DVbb
    conduit-1.3.6.1-33PyKFsamc3EFWlmJ7D0Br
    conduit-extra-1.3.8-7VOS9GlqqXhBvb6VdV8TEx containers-0.6.7
    crypton-1.0.4-GYTsR9n7Zq1ECMMDOmhNUo
    crypton-conduit-0.2.3-9fPGbv904rXJF2GezJKSkP deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-Hzfeza2Hq5dILJ5nNY03vc filepath-1.4.300.1
    fsnotify-0.4.4.0-1axTkdclzBwBHTwYFFOczM
    generic-deriving-1.14.7-5esUjc0ZD1xDonHU88xHPs
    hackage-security-0.6.3.2-1KRJUuoa1VN1tmaTwxFJo6
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    hi-file-parser-0.1.8.0-GxL501hl1o9EXPhNgwiBBz
    hpack-0.38.0-2Lsz47NnhGv9BnI63ZGiRl hpc-0.6.2.0
    http-client-0.7.19-BuEJUWBQ6l56XQSn4y9UoM
    http-client-tls-0.3.6.4-Bp5cRUa8ezODKJhpkb8FwG
    http-conduit-2.3.9.1-Dpr7KR5oYZfA1uRBfsTNny
    http-download-0.2.1.0-KbHKTWhmRhl1cuBL4ACX19
    http-types-0.12.4-GbnA9GBjJLTWEnI56wc3O
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-GFacZ5dqq7HIQXvHwprO7 mtl-2.3.1
    mustache-2.4.3.1-G9jzCdmikjm14zt2U6gLFF
    neat-interpolation-0.5.1.4-1lVbJTTfuquHYKgw1skr06
    network-uri-2.6.4.2-IMX0mANgtbEDPhppJ5beX9
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-CWeKmfCITC3AeEtxQrg6nv
    pantry-0.8.3-9bOJdrQGq4z63HJlS6Yzcp
    path-0.9.6-7UHcb1fB45F4a2cIRwFwXo
    path-io-1.8.2-JkHOPUc9RpPo2XuDaIwqc
    persistent-2.14.5.2-FAwgt6nNomG3D4QE8cObIU
    persistent-sqlite-2.13.2.0-KPtxLXhkYAxG2fD79yVKDy pretty-1.1.3.6
    primitive-0.9.1.0-L0TzPG8QAUj5rYJTRwJ4yF process-1.6.19.0
    project-template-0.2.1.0-63awq7as6euCS31bsUgRcp
    random-1.2.1.3-Lrunn7lr3eYBt1jhWQyV5S
    retry-0.9.3.1-HHBGAfoPfIuGIkanwMzQJD
    rio-0.1.24.0-8jLMpmKpTUU7IJnoe6MpLH
    rio-prettyprint-0.1.8.0-6VJcOedy3Rz81Bmc52TBlk
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-DQzXRCxPqvy6dF3GI89UsZ
    tar-0.5.1.1-C22o33WpWTZ6GvByDwVEJG template-haskell-2.20.0.0
    temporary-1.3-EZyCN0IpTQNJIMCpUwiknJ text-2.0.2
    text-metrics-0.3.3-F1tb054BgK62wOC1xBde4T
    th-reify-many-0.1.10-2QisnA6taf4psTZd2jX03 time-1.12.2
    tls-2.0.6-ys5gm9uWBaFvFy3tx7Q6D transformers-0.6.1.0
    typed-process-0.2.13.0-EjkgLhOGB7RChUvadFGhIw
    unicode-transforms-0.4.0.1-93dRLjcSA2uLkOuhkiMF5T unix-2.8.4.0
    unix-compat-0.7.4.1-3PiPvN0U02MHmC07m9SIp2
    unliftio-0.2.25.1-2YWCJQ4bXOaKV2dFmJlGMH
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh
    vector-0.13.2.0-2vFNmgih5WRFjWzUm3LR1R
    yaml-0.11.11.2-BrONu46BlbNIwRjX8TXq4h
    zip-archive-0.4.3.2-75kJTv7ekaHBH0ddncUVNb
    zlib-0.7.0.0-5sa31OYxcwF6Cz3PdoChDq

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

